MutationRef<Data, Variables> class

Inheritance

Constructors

MutationRef(FirebaseDataConnect dataConnect, String operationName, DataConnectTransport transport, Deserializer<Data> deserializer, Serializer<Variables> serializer, Variables? variables)

Properties

dataConnect FirebaseDataConnect
finalinherited
deserializer Deserializer<Data>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
operationId String
latefinalinherited
operationName String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializer Serializer<Variables>
finalinherited
variables → Variables?
finalinherited

Methods

execute() Future<OperationResult<Data, Variables>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited