OperationRef<Data, Variables> class abstract

Reference to a specific query. Contains variables, transport to execute queries, and serialization/deserialization strategies.

Implementers

Constructors

OperationRef(FirebaseDataConnect dataConnect, String operationName, DataConnectTransport _transport, Deserializer<Data> deserializer, Serializer<Variables> serializer, Variables? variables)
Constructor

Properties

dataConnect FirebaseDataConnect
final
deserializer Deserializer<Data>
final
hashCode int
The hash code for this object.
no setterinherited
operationId String
latefinal
operationName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializer Serializer<Variables>
final
variables → Variables?
final

Methods

execute() Future<OperationResult<Data, Variables>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createOperationId<Variables>(String operationName, Variables? vars, Serializer<Variables>? serializer) String