CacheSettings class
Configuration for the cache
Constructors
- CacheSettings({CacheStorage? storage, Duration maxAge = Duration.zero})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAge → Duration
-
Duration for which cache is used before revalidation with server
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage → CacheStorage
-
The type of storage to use (e.g., "persistent", "memory")
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited