QueryRef<Data, Variables> class
- Inheritance
-
- Object
- OperationRef<
Data, Variables> - QueryRef
Constructors
-
QueryRef(FirebaseDataConnect dataConnect, String operationName, DataConnectTransport transport, Deserializer<
Data> deserializer, QueryManager _queryManager, Serializer<Variables> serializer, Variables? variables)
Properties
- dataConnect → FirebaseDataConnect
-
finalinherited
-
deserializer
→ Deserializer<
Data> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- operationId → String
-
latefinalinherited
- operationName → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serializer
→ Serializer<
Variables> -
finalinherited
- variables → Variables?
-
finalinherited
Methods
-
execute(
{QueryFetchPolicy fetchPolicy = QueryFetchPolicy.preferCache}) → Future< QueryResult< Data, Variables> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publishErrorToStream(
Object err) → void -
publishResultToStream(
QueryResult< Data, Variables> result) → void -
subscribe(
) → Stream< QueryResult< Data, Variables> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited